'''
Defines abstract classes representing the interfaces that must be implemented
by a monitor for LSR.

@author: Peter Parente
@organization: IBM Corporation
@copyright: Copyright (c) 2005, 2007 IBM Corporation
@license: The BSD License

All rights reserved. This program and the accompanying materials are made 
available under the terms of the BSD license which accompanies
this distribution, and is available at
U{http://www.opensource.org/licenses/bsd-license.php}
'''
from Base import AEMonitor
from MonitorCollection import MonitorCollection